# pysolorie

[![Quality Checks](https://github.com/aaghamohammadi/pysolorie/actions/workflows/quality_checks.yml/badge.svg?branch=main)](https://github.com/aaghamohammadi/pysolorie/actions/workflows/quality_checks.yml)
[![Publish](https://github.com/aaghamohammadi/pysolorie/actions/workflows/publish.yml/badge.svg?branch=main)](https://github.com/aaghamohammadi/pysolorie/actions/workflows/publish.yml)
![GitHub License](https://img.shields.io/github/license/aaghamohammadi/pysolorie)
![PyPI - Downloads](https://img.shields.io/pypi/dm/pysolorie)



Orientation Analysis of Solar Panel
